nbxmpp.idlequeue.IdleObject

Package nbxmpp :: Module idlequeue :: Class IdleObject |
[hide private]
[frames] | no frames]

# Class IdleObject

source code

Idle listener interface. Listed methods are called by IdleQueue.

Instance Methods | [hide private]
__init__(self) | source code
pollend(self) Called on stream failure | source code
pollin(self) Called on new read event | source code
pollout(self) Called on new write event (connect in sockets is a pollout) | source code
read_timeout(self) Called when timeout happened | source code

Instance Variables | [hide private]
| fd filedescriptor, must be unique for each IdleObject

Method Details | [hide private]

### __init__(self) (Constructor) | source code

### pollend(self) | source code
Called on stream failure

### pollin(self) | source code
Called on new read event

### pollout(self) | source code
Called on new write event (connect in sockets is a pollout)

### read_timeout(self) | source code
Called when timeout happened

Instance Variable Details | [hide private]

### fd filedescriptor, must be unique for each IdleObject